@@ -131,7 +131,7 @@ function(out,model,adjust,realvcv=FALSE,vcvfile)
   x3=length(out)
   if(length(grep("proc stop",out,ignore.case=TRUE))==0)
      message("\nWarning: output from MARK was not complete\n")
-  x4=grep("Variable   Value",out,ignore.case=FALSE)+1
+  x4=grep("Variable[ ]*Value",out,ignore.case=FALSE)+1
   if(length(x4)==0)x4=x2
 #
 # Extract average covariate values used in real parameter calculation
@@ -140,7 +140,9 @@ function(out,model,adjust,realvcv=FALSE,vcvfile)
   {
      ff <- tempfile()
      cat(file=ff, out[(x4+1):(x4+length(model$covariates))],sep="\n")
-     covariate.values=read.fwf(file=ff,widths=c(20,15),col.names=c("Variable","Value"))
+     clength=nchar(out[(x4 + 1):(x4 + length(model$covariates))])[1]
+     covariate.values=read.fwf(file = ff, widths = c(clength-15,clength),col.names = c("Variable", "Value"))
+     ##covariate.values=read.fwf(file=ff,widths=c(20,30),col.names=c("Variable","Value"))
   }
   else
      covariate.values=NULL
@@ -249,6 +251,7 @@ function(out,model,adjust,realvcv=FALSE,vcvfile)
     real.vcv=param$real.vcv
   else
     real.vcv=NULL
+  if(!is.matrix(param$beta.vcv))param$beta.vcv=as.matrix(param$beta.vcv)
   if(is.null(npar.unadjusted))
      return(list(lnl=lnl,deviance=deviance,deviance.df=deviance.df,npar=npar,n=n,AICc=AICc,beta=beta,real=real,beta.vcv=param$beta.vcv,derived=param$derived,derived.vcv=param$derived.vcv,
                  covariate.values=covariate.values,singular=singular,real.vcv=real.vcv))
